@@ -1,7 +1,7 @@
 from ellipsis.path.raster.root import editBand
-from ellipsis.path.raster.root import editMap
+from ellipsis.path.raster.root import edit
 from ellipsis.path.raster import timestamp
-from ellipsis.path.raster import layer
+from ellipsis.path.raster import style
 
 
 
